@@ -4,32 +4,33 @@ use 5.007003;
 use strict;
 use warnings;
 
-use base   qw/Exporter DynaLoader/;
+use base qw/Exporter DynaLoader/;
 use Symbol qw/qualify_to_ref/;
-use Carp   qw/croak/;
+use Carp qw/croak/;
 
-BEGIN {
-	our $VERSION = '0.03_2';
+our $VERSION = '0.03_3';
 
-	our @EXPORT_OK = qw/map_handle map_file map_anonymous sync locked unmap/;
+our (@EXPORT_OK, %EXPORT_TAGS);
 
-	our %EXPORT_TAGS = (
-		MAP       => [qw/map_handle map_file map_anonymous unmap/],
-	);
+bootstrap Sys::Mmap::Simple $VERSION;
 
-	bootstrap Sys::Mmap::Simple $VERSION;
+my %export_data = (
+	MAP       => [qw/map_handle map_file map_anonymous remap unmap/],
+	EXTRA     => [qw/sync locked/],
+	CONDITION => [qw/condition_wait condition_signal condition_broadcast/],
+);
 
-	if (defined &condition_wait) {
-		my @cond_funcs = qw/condition_wait condition_signal condition_broadcast/;
-		push @EXPORT_OK, @cond_funcs;
-		$EXPORT_TAGS{CONDITION} = \@cond_funcs;
+while (my ($category, $values) = each %export_data) {
+	for my $function (grep { defined &{$_} } @{$values}) {
+		push @EXPORT_OK, $function;
+		push @{ $EXPORT_TAGS{$category} }, $function;
 	}
 }
 
 sub map_handle(\$*@) {
 	my ($var_ref, $glob, $writable) = @_;
 	my $fh = qualify_to_ref($glob, caller);
-	return _mmap_wrapper($var_ref, -s $fh, defined $writable ? $writable : 0, fileno $fh);
+	return _mmap_wrapper($var_ref, -s $fh, $writable ? $writable : 0, fileno $fh);
 }
 
 sub map_file(\$@) {
@@ -45,7 +46,7 @@ sub _mmap_wrapper {
 	my $ret;
 	eval { $ret = _mmap_impl(@_) };
 	if ($@) {
-		$@ =~ s/\n$//m;
+		$@ =~ s/\n$//mx;
 		croak $@;
 	}
 	return $ret;
@@ -61,7 +62,7 @@ Sys::Mmap::Simple - Memory mapping made simple and safe.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -78,9 +79,11 @@ This module maps files to Perl variables. There are a few differences between th
 
 =over 4
 
-=item * It offers a more simple interface. It always maps the whole file, and always does shared mapping. This seems to be what people want in 95% of all cases.
+=item * It offers a more simple interface targeted at common usage patterns: It always maps the whole file, and always does shared mapping. This seems to be what people want in almost all cases.
 
-=item * This module is safe yet fast. Sys::Mmap offers two interfaces, one is fast, but can lose its cou segfault if not used correctly. The other is safe, but reportedly 10 times slower. Sys::Mmap::Simple is fast (as long as it is used properly) and safe.
+=item * It is portable, supporting not only unix but also windows.
+
+=item * This module is safe yet fast. Sys::Mmap offers two interfaces, one is fast, but can cause segfault or loose the mapping if not used correctly. The other is safe, but reportedly 10 times slower. Sys::Mmap::Simple is fast (as long as it is used properly) and safe.
 
 =item * It will automatically unmap the file when the scalar gets destroyed.
 
@@ -92,7 +95,7 @@ This module maps files to Perl variables. There are a few differences between th
 
 =head2 MAPPING
 
-The following functions for mapping a variable are availible for exportation. They all take an lvalue as their first argument.
+The following functions for mapping a variable are available for exportation. They all take an lvalue as their first argument.
 
 =head3 map_handle $variable, *handle, $writable = 0
 
@@ -110,6 +113,10 @@ Map an anonymous piece of memory.
 
 Flush changes made to the memory map back to disk. Mappings are always synced when unmapped, so this is usually not necessary. 
 
+=head3 remap $variable, $new_size
+
+Try to remap $variable to a new size. It may fail if there is not sufficient space to expand a mapping at its current location. This call is linux specific and currently not supported or even defined on other systems.
+
 =head3 unmap $variable
 
 Unmap a variable. Note that normally this is not necessary, but it is included for completeness.
@@ -120,25 +127,29 @@ These locking functions provide thread based locking for the mapped region. The
 
 =head3 locked { block } $variable
 
-Perform an action while keeping a thread lock on the map. The map is accessable as C<$_>. It will return whatever its block returns.
+Perform an action while keeping a thread lock on the map. The map is accessible as C<$_>. It will return whatever its block returns.
 
 =head3 condition_wait { block }
 
-While the block is false, wait for signals.
+Wait for block to become true. After every failed try, wait for a signal. It returns the value returned by the block.
 
 =head3 condition_signal
 
-This will signal to one listener that the map is availible.
+This will signal to one listener that the map is available.
 
 =head3 condition_broadcast
 
-This will signal to all listeners that the map is availible.
+This will signal to all listeners that the map is available.
 
 =head1 DIAGNOSTICS
 
 If you C<use warnings>, this module will give warnings if the variable is improperly used (anything that changes its size). This can be turned off lexically by using C<no warnings 'substr'>.
 
-Trying to sync or unmap a variable that hasn't been mapped will result in an exception.
+Trying to sync, remap, unmap or lock a variable that hasn't been mapped will cause an exception to be thrown.
+
+=head1 DEPENDENCIES
+
+This module does not have any dependencies on other modules.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -158,7 +169,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Sys::Mmap::Simple
 
-
 You can also look for information at:
 
 =over 4
